
# Mario Utils

This project is used as a Python library for managing database connections (Now just supporting SQLServer over pymssql) and Logging for future scripts, avoiding boilerplate code.


## Authors

- [@MarioHdzCtu](https://github.com/MarioHdzCtu)

